@@ -389,6 +389,9 @@ RESOURCENOTFOUND_LIFECYCLEHOOKINSTANCENOTFOUND = 'ResourceNotFound.LifecycleHook
 # 无法找到指定生命周期挂钩。
 RESOURCENOTFOUND_LIFECYCLEHOOKNOTFOUND = 'ResourceNotFound.LifecycleHookNotFound'
 
+# 指定的生命周期挂钩Token不存在。
+RESOURCENOTFOUND_LIFECYCLEHOOKTOKENNOTFOUND = 'ResourceNotFound.LifecycleHookTokenNotFound'
+
 # 指定的Listener不存在。
 RESOURCENOTFOUND_LISTENERNOTFOUND = 'ResourceNotFound.ListenerNotFound'
 
@@ -428,6 +431,9 @@ RESOURCEUNAVAILABLE_CMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.CmqTopicHasNo
 # 实例和伸缩组Vpc不一致。
 RESOURCEUNAVAILABLE_CVMVPCINCONSISTENT = 'ResourceUnavailable.CvmVpcInconsistent'
 
+# 绑定负载均衡器的伸缩组禁止修改Vpc。
+RESOURCEUNAVAILABLE_FORBIDDENMODIFYVPC = 'ResourceUnavailable.ForbiddenModifyVpc'
+
 # 实例无法添加至伸缩组。
 RESOURCEUNAVAILABLE_INSTANCECANNOTATTACH = 'ResourceUnavailable.InstanceCannotAttach'
 
