@@ -77,6 +77,9 @@ INTERNALERROR_DECRYPTION = 'InternalError.Decryption'
 # 依赖的其他api出错。
 INTERNALERROR_DEPENDSAPI = 'InternalError.DependsApi'
 
+# 数据库异常。
+INTERNALERROR_DEPENDSDB = 'InternalError.DependsDb'
+
 # 加密错误。
 INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 
